# pyschedge

pyschedge is a python wrapper for the [Schedge API](https://schedge.a1liu.com).

# Formatting
Run `black src` before committing to ensure codes are formatted.

# Development
1. Run `python3 -m venv env` for a virtual environment
2. Install all the dependencies `pip install -r requirements.txt`
3. Run `deactivate` to exit your virtual environment